@@ -65,7 +65,7 @@ data source.
 
 =over 4
 
-=item new
+=item new()
 
 This method initializes the user object. It takes one parameter, the username.
 
@@ -84,7 +84,7 @@ Example:
 
 =over 4
 
-=item attribute
+=item attribute()
 
 Set/Returns a user object attribute.
 
@@ -118,11 +118,13 @@ Example:
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffold::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
  Scaffold::Stash::Controller
  Scaffold::Stash::Cookie
+ Scaffold::Stash::Manager
  Scaffold::Stash::View
  Scaffold::Uaf::Authenticate
  Scaffold::Uaf::AuthorizeFactory
@@ -137,7 +139,7 @@ Example:
 
 =head1 AUTHOR
 
-Kevin L. Esteb
+Kevin L. Esteb E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
